pilas.fisica.Circulo

Package pilas :: Module fisica :: Class Circulo |
[hide private]
[frames] | no frames]

# Class Circulo

source code

    object --+
             |
        Figura --+
                 |
                Circulo

Representa un cuerpo de circulo.

Generalmente estas figuras se pueden construir independientes de un actor, y luego asociar.

Por ejemplo, podríamos crear un círculo:

    >>> circulo_dinamico = pilas.fisica.Circulo(10, 200, 50)

y luego tomar un actor cualquiera, y decirle que se comporte cómo el circulo:

    >>> mono = pilas.actores.Mono()
    >>> mono.imitar(circulo_dinamico)

Instance Methods | [hide private]
__init__(self, x, y, radio, dinamica=True, densidad=1.0, restitucion=0.56, friccion=10.5, amortiguacion=0.1, fisica=None, sin_rotacion=False) x.__init__(...) initializes x; see help(type(x)) for signature | source code
Inherited from `Figura`: `definir_posicion`, `definir_rotacion`, `definir_velocidad_lineal`, `definir_x`, `definir_y`, `detener`, `eliminar`, `empujar`, `impulsar`, `obtener_rotacion`, `obtener_velocidad_lineal`, `obtener_x`, `obtener_y` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `Figura`: `rotacion`, `x`, `y` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, x, y, radio, dinamica=True, densidad=1.0, restitucion=0.56, friccion=10.5, amortiguacion=0.1, fisica=None, sin_rotacion=False) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)